################ IMPORTS #############################################
import asyncio
from idun_guardian_sdk import GuardianClient
import spotipy
from spotipy.oauth2 import SpotifyOAuth

#################### Configuration ####################
# Recording settings
RECORDING_TIMER = int(60 * 5) # 5 minutes
LED_SLEEP = False

# Device ID
my_api_token = "INSERT_HERE"
device_address = "INSERT_HERE"

# Spotify configuration for music control
sp = spotipy.Spotify(auth_manager=SpotifyOAuth(
    client_id="INSERT_HERE",
    client_secret="INSERT_HERE",
    redirect_uri="http://localhost:8888/callback",
    scope="user-modify-playback-state user-read-playback-state"
    ))

#################### Music control ####################
def toggle_music():
    """
    Pause or start the music playback
    """
    playback = sp.current_playback()

    if playback and playback['is_playing']:
        sp.pause_playback()
    else:
        sp.start_playback()

def next_track():
    """
    Play the next track
    """
    sp.next_track()

def previous_track():
    """
    Play the previous track
    """
    sp.previous_track()

#################### Handler functions ####################
def pred_handler(event):
    """
    Handler for the live prediction data
    """
    # Jaw clench -> toggle playlist
    if any('predictionResponse' in key for key in event.message):
        jaw_clenches = event.message["predictionResponse"]
        binary_jaw_clenches = [0 if jaw_clench == 'Nothing' else 1 for jaw_clench in jaw_clenches]

        if any([pred > 0 for pred in binary_jaw_clenches]):
            print('Jaw clench detected', flush=True)
            toggle_music()

    # HEOG -> switch track
    if any("heogClassificationsResponse" in key for key in event.message):
        heog = event.message["heogClassificationsResponse"]

        if any([pred == 1 for pred in heog]):
            print('Left HEOG detected', flush=True)
            previous_track()

        if any([pred == 2 for pred in heog]):
            print('Right HEOG detected', flush=True)
            next_track()


#################### Main ####################
if __name__ == "__main__":
    
    # Create client
    client = GuardianClient(api_token=my_api_token, address=device_address)

    # Subscribe to live predictions
    client.subscribe_realtime_predictions(jaw_clench=True, fft=False, bin_heog=True, handler=pred_handler)

    # Start the recording
    asyncio.run(
        client.start_recording(
            recording_timer=RECORDING_TIMER, led_sleep=LED_SLEEP, calc_latency=False
        )
    )

    # Prints and downloads
    rec_id = client.get_recording_id()
    print("RecordingId", rec_id)